<template>
  <div v-if="display">
    <vciWebReferClassify
        :key="typeKey" :data-key="typeKey"
        :disabled="disabled"
        :referConfig="rConfig"
        :referType="referType"
        :text="textD"
        :title="titleD"
        :value="valueD"
        :width="width"
        :height="height"
        :reloadFormKey="reloadFormKey"
        @setReferValue="setValue">
    </vciWebReferClassify>
  </div>
</template>

<script>
import vciWebReferClassify from "./vciWebReferClassify.vue";
import {verifyNull} from "@/util/validate";

export default {
  name: "orgUserRefer",
  props: {
    referConfig: {
      type: Object,
    }, value: {
      type: String,
      default: ''
    }, text: {
      type: String,
      default: ''
    }, disabled: {
      type: Boolean,
      default: false,
    }, display: {
      type: Boolean,
      default: true
    }, typeKey: {
      type: String,
      default: ''
    }, referType: {
      type: String,
      default:''
    }, width: {
      type: String,
      default:'70%'
    }, height: {
      type: String,
      default:(document.body.clientHeight-400)+'px'
    },
    reloadFormKey: {
      type: String,
      default: '',
    }
  },
  components: {vciWebReferClassify },
  data() {
    return {
      emitData: {},
    };
  },
  computed: {
    rConfig() {
      let rConfig = this.referConfig;
      if (!rConfig.options) {
        rConfig.options = {};
      }
      rConfig.options.isMuti = rConfig.options.muti || rConfig.options.isMuti || false;
      rConfig.options.url='/org/userQueryController/referGrid';
      rConfig.options.width=this.referConfig.options.width || '80%';
      rConfig.options.tableConfig={
        cols:[{
          prop: 'code',
          label: (this.$project.user.code || "账号"),
          sortable: true,
          search: true
        },{
          prop: 'name',
          label: '姓名',
          sortable: true,
          search: true
        },  {
          prop: 'deptIdName',
          label: '所属部门',
        },  {
          prop: 'sexText',
          label: '性别',
        }]
      };
      rConfig.options.classifys=[{
        title:'部门',
        treeUrl:'/org/deptController/referGrid', //分类的路径
        queryByClassifyUrl:'/permission/userQueryController/gridUserByDeptIdGet',  //'列表'
        queryField:'deptId', //列表数据中分类的字段
        classifyValueField:'id',  //从树上获取的字段
      },{
        title:'角色',
        treeUrl:'/permission/roleController/referGrid', //分类的路径
        queryByClassifyUrl:'/permission/userQueryController/gridUserInRoleIdGet',  //'列表'
        queryField:'roleId', //列表数据中分类的字段
        classifyValueField:'id',  //从树上获取的字段
      }];
      rConfig.options.onlyTable=false;
      return rConfig;
    },
    titleD(){
      let title = this.referConfig.title || "";
      title = title.replace(":", "");
      title = title
          ? "为【" + title + "】选取值"
          : "为【" + this.referConfig.showProp + "】选取值";
      return title;
    },
    textD(){
      return verifyNull(this.text) ? (this.referConfig.options.defalutText || '') : this.text;
    },
    valueD(){
      return verifyNull(this.value) ? (this.referConfig.options.defalutValue || '') :this.value;
    }
  },
  created() {
  },
  methods: {
    setValue(value) {
      this.emitData = value;
    }
  },
  watch: {
    // 修改反馈到父组件
    emitData: {
      deep: true,
      handler(newV) {
        this.$emit("setReferValue", newV);
      }
    }
  }
};
</script>

<style scoped>

</style>
